@@ -26,3 +26,15 @@ def get_phone_dist(transOne,transTwo):
             dist += 1
     return dist
 
+
+def fix_many_to_many():
+    qs = WordForm.objects.all().prefetch_related('orthographies')
+    l = lambda x: (x.orthography,x.word_form,x.frequency)
+    for w in qs:
+        dups = []
+        ss = w.spelledas_set.all()
+        for s in ss:
+            if l(s) not in map(l,dups) and map(l,ss).count(l(s)) > 1:
+                dups.append(s)
+        for s in dups:
+            s.delete()
